@@ -14,7 +14,7 @@
 class TAutoconfLdap : public AutoconfigKolabLdap
 {
 public:
-    void startJob(const QUrl &url) Q_DECL_OVERRIDE
+    void startJob(const QUrl &url) override
     {
         QCOMPARE(url, expectedUrls.takeFirst());
         if (replace.contains(url)) {
